import {
  defineComponent,
  ref,
  reactive,
  watch,
  watchEffect,
  onMounted,
  computed,
  onUnmounted,
} from 'vue';

import { useRouter, useRoute } from 'vue-router';
import { useCommonStore, useIncidentStore } from '@/store';
import useMarkerStore from '@/store/useMarkerStore';
import {
  DropdownItemOption,
  NavBar,
  DropdownMenu,
  DropdownItem,
  Icon,
  PullRefresh,
  List,
} from 'vant';
import './index.scss';
import { IncidentItem } from '@/api/incident';

const baseIncidentTypeOptions: DropdownItemOption[] = [
  { text: '事件类型', value: '' },
];
const baseIncidentLevelOptions: DropdownItemOption[] = [
  { text: '事件等级', value: '' },
];

export default defineComponent({
  name: 'Home',
  setup() {
    const refreshLoading = ref(false);
    const listLoading = ref(false);
    const listFinished = ref(false);

    const router = useRouter();
    const route = useRoute();
    const store = useIncidentStore();
    const commonStore = useCommonStore();
    const incidentType = ref('');
    const incidentLevel = ref('');
    const incidentTypeOptions = computed(() =>
      baseIncidentTypeOptions.concat(
        commonStore.globalDict['zhdd_incident_type']?.map(
          (o) =>
            ({
              text: o.dictLabel,
              value: o.dictValue,
            } ?? []),
        ) as DropdownItemOption[],
      ),
    );
    const incidentLevelOptions = computed(() =>
      baseIncidentLevelOptions.concat(
        commonStore.globalDict['zhdd_incident_level']?.map(
          (o) =>
            ({
              text: o.dictLabel,
              value: o.dictValue,
            } ?? []),
        ) as DropdownItemOption[],
      ),
    );

    const list = ref<IncidentItem[]>([]);

    const pageNum = ref(1);

    const handleRefresh = async () => {
      listFinished.value = false;
      pageNum.value = 1;
      listLoading.value = true;
      handleLoad();
    };
    const handleLoad = async () => {
      if (refreshLoading.value) {
        list.value = [];
        refreshLoading.value = false;
      }
      await store.getIncidentList({
        type: incidentType.value,
        level: incidentLevel.value,
        // status: '3',
        pageNum: (pageNum.value += 1),
        pageSize: 10,
      });
      // if (store.)
      list.value.push(...(store.incidents.rows ?? []));
      if (list.value.length >= (store.incidents.total ?? 0)) {
        listFinished.value = true;
      }
      listLoading.value = false;
    };

    const handleLinkDetail = (id: string) => {
      router.push(`/status/3/detail?id=${id}`);
    };

    watch(
      [() => incidentLevel.value, () => incidentType.value],
      ([nextLevel, nextType], [preLevel, preType]) => {
        console.log('next', nextLevel, nextType);
        console.log('pre', preLevel, preType);
        store.getIncidentList({
          type: nextType,
          level: nextLevel,
          // status: '3',
          pageNum: 1,
          pageSize: 10,
        });
      },
    );

    onMounted(() => {
      commonStore.getGlobalDict('zhdd_incident_level');
      commonStore.getGlobalDict('zhdd_incident_type');
      store.getIncidentList({
        pageNum: 1,
        // status: '3',
        pageSize: 10,
      });
    });
    onUnmounted(() => {});

    return () => (
      <div class="home-container">
        <NavBar
          title="应急处置"
          left-arrow
          fixed
          onClickRight={() => router.push(`/status/${route.params.status}/report`)}
          v-slots={{ right: () => <Icon name="plus" /> }}
          style={{ zIndex: 2 }}
        />
        <div style={{ position: 'sticky', top: '46px', zIndex: 1 }}>
          <DropdownMenu>
            <DropdownItem
              v-model={incidentType.value}
              options={incidentTypeOptions.value}></DropdownItem>
            <DropdownItem
              v-model={incidentLevel.value}
              options={incidentLevelOptions.value}></DropdownItem>
          </DropdownMenu>
        </div>
        <PullRefresh
          onRefresh={handleRefresh}
          v-model={refreshLoading.value}
          successText="刷新成功">
          <div class="home-content">
            <List
              v-model:loading={listLoading.value}
              finished={listFinished.value}
              finished-text="没有更多了"
              onLoad={handleLoad}>
              {store.incidents?.rows?.map((item) => (
                <div
                  class="incident-item"
                  key={item.id}
                  onClick={() => {
                    item.id && handleLinkDetail(item.id);
                  }}>
                  <div class="title">{item.name}</div>
                  <p>
                    事件类型：
                    {
                      commonStore.globalDict['zhdd_incident_type']?.find(
                        (o) => o.dictValue.toString() === item.type?.toString(),
                      )?.dictLabel
                    }
                  </p>
                  <p>
                    事件等级：
                    {
                      commonStore.globalDict['zhdd_incident_level']?.find(
                        (o) =>
                          o.dictValue.toString() === item.level?.toString(),
                      )?.dictLabel
                    }
                  </p>
                  <p>事件时间：{item.createTime}</p>
                  <p>地点：{item.addr}</p>
                  <p>事件来源：{item.source}</p>
                </div>
              ))}
            </List>
          </div>
        </PullRefresh>
      </div>
    );
  },
});
