import { ref, defineComponent, computed, onMounted, onUnmounted } from 'vue';
import { useRoute, useRouter } from 'vue-router';
import cloneDeep from 'lodash/cloneDeep';
import div from '@/components/div';
import { useCommonStore, useIncidentStore } from '@/store';
import QueryMap from '@/components/QueryMap';
// import MediaUpload from '@/components/MediaUpload';
import './index.scss';
import {
  DropdownItemOption,
  NavBar,
  DropdownMenu,
  DropdownItem,
  Icon,
  PullRefresh,
  Sticky,
  Collapse,
  CollapseItem,
  Loading,
  Form,
  Field,
  CellGroup,
  Popup,
  Picker,
  ActionBar,
  Button,
  Notify,
  Uploader,
} from 'vant';

export default defineComponent({
  name: 'IncidentManagementReport',
  setup() {
    const store = useIncidentStore();
    const commonStore = useCommonStore();
    const detail = computed(() => store.incidentDetail?.baseInfo);
    const addr = ref('');

    const form = ref({ ...detail.value });
    const formRef = ref();

    const showCreateByPicker = ref(false);

    const route = useRoute();
    const router = useRouter();

    const handleSaveReport = () => {
      const { id } = route.query;

      const saveFn = id ? store.putIncidentItem : store.postIncidentItem;

      formRef.value.validate(async (valid: boolean) => {
        if (valid) {
          if (!form.value.locations) {
            Notify({
              type: 'danger',
              message: '需要点击确认按钮确认是否正确',
            });
            return;
          }
          const result = await saveFn({
            ...form.value,
            level: Number(form.value.level) ?? null,
            type: Number(form.value.type) ?? null,
            status: route.params.status as unknown as number,
          });
          if (result) {
            router.replace(
              `/incident-management/status/${route.params.status}`,
            );
          }
        }
      });
    };

    onMounted(async () => {
      commonStore.getGlobalDict('zhdd_incident_level');
      commonStore.getGlobalDict('zhdd_incident_type');
      commonStore.getGlobalDict('zhdd_org_upload');

      route.query.id && (await store.getIncidentItem(route.query.id as string));
      addr.value = detail?.value?.addr ?? '';
      if (detail.value) {
        form.value = cloneDeep(detail.value);
      }
    });

    onUnmounted(() => {
      commonStore.uploadFiles = [];
      store.incidentDetail = {};
      store.incidentDetail = {
        baseInfo: {},
        process: [],
        task: [],
      };
    });

    return () => (
      <div class="incident-report-container ">
        <NavBar
          title="应急处置"
          left-arrow
          fixed
          onClick-left={() => router.push('/home')}
        />
        <Form>
          <CellGroup>
            <Field
              v-model={form.value.name}
              name="事件标题"
              label="事件标题"
              placeholder="请输入"
              required
              rules={[{ required: true, message: '事件标题必填' }]}
            />
            <Field
              v-model={form.value.createBy}
              name="上报人"
              label="上报人"
              placeholder="请输入"
              required
              rules={[{ required: true, message: '上报人必填' }]}
            />
            <Field
              v-model={form.value.createDept}
              name="上报单位"
              label="上报单位"
              placeholder="请输入"
              required
              rules={[{ required: true, message: '上报单位必填' }]}
            />
            <Field
              v-model={form.value.type}
              is-link
              readonly
              name="事件类型"
              label="事件类型"
              placeholder="请选择"
              required
              rules={[{ required: true, message: '事件类型必填' }]}
              onClick={() => (showCreateByPicker.value = true)}
            />
            <Popup v-model:show={showCreateByPicker.value} position="bottom">
              <Picker
                columns={commonStore.globalDict['zhdd_incident_type']?.map(
                  (i) => ({ text: i.dictLabel, value: i.dictValue }),
                )}
                onConfirm={(value) => {
                  form.value.type = value.text;
                  console.log(value, '---');

                  showCreateByPicker.value = false;
                }}
                onCancel={() => {
                  showCreateByPicker.value = false;
                }}
              />
            </Popup>
            <Field
              v-model={form.value.level}
              is-link
              readonly
              name="事件等级"
              label="事件等级"
              placeholder="请选择"
              required
              rules={[{ required: true, message: '事件等级必填' }]}
              onClick={() => (showCreateByPicker.value = true)}
            />
            <Popup v-model:show={showCreateByPicker.value} position="bottom">
              <Picker
                columns={commonStore.globalDict['zhdd_incident_level']?.map(
                  (i) => ({ text: i.dictLabel, value: i.dictValue }),
                )}
                onConfirm={(value) => {
                  form.value.type = value.text;
                  console.log(value, '---');

                  showCreateByPicker.value = false;
                }}
                onCancel={() => {
                  showCreateByPicker.value = false;
                }}
              />
            </Popup>
            <Field
              v-model={form.value.des}
              rows={2}
              autosize
              name="事件描述"
              label="事件描述"
              type="textarea"
              placeholder="请输入"
            />
            <Field
              v-model={form.value.addr}
              name="事件地点"
              label="事件地点"
              placeholder="请输入"
              required
              onChange={(add: string) => {
                addr.value = add.target.value;
              }}
              rules={[{ required: true, message: '事件地点必填' }]}
            />
            <QueryMap
              address={addr.value}
              v-model:locations={form.value.locations}
              v-model:longitude={(form.value.locations ?? '').split(',')[0]}
              v-model:latitude={(form.value.locations ?? '').split(',')[1]}
              onChoose={(name) => {
                form.value.addr = name;
              }}
              onRestPositon={() => {
                addr.value = store.incidentDetail.baseInfo?.addr ?? '';
                form.value.addr = store.incidentDetail.baseInfo?.addr;
                form.value.locations = store.incidentDetail.baseInfo?.locations;
              }}
            />
            <Field
              name="上传视频"
              label="上传视频"
              placeholder="请输入"
              v-slots={{
                input: () => (
                  <Uploader accept="video/*" v-model={form.value.video} />
                ),
              }}
            />
            <Field
              name="上传图片"
              label="上传图片"
              placeholder="请输入"
              v-slots={{
                input: () => (
                  <Uploader accept="image/*" v-model={form.value.pic} />
                ),
              }}
            />
          </CellGroup>
          <div style={{ height: '80px' }}></div>

          <ActionBar>
            <div style={{ padding: '10px 20px' }}>
              <Button block type="primary" onClick={handleSaveReport}>
                提交
              </Button>
            </div>
          </ActionBar>
        </Form>
        {/* <el-form ref={formRef} model={form} label-width="120px">
          <el-form-item
            label="事件标题"
            required
            prop="name"
            rules={{ required: true, message: '事件标题必填' }}>
            <el-input
              v-model={form.value.name}
              placeholder="请输入"
              size="small"
            />
          </el-form-item>
          <el-row>
            <el-col span={12}>
              <el-form-item
                label="上报人"
                required
                prop="createBy"
                rules={{ required: true, message: '上报人必填' }}>
                <el-input
                  size="small"
                  v-model={form.value.createBy}
                  placeholder="请输入"
                />
              </el-form-item>
            </el-col>
            <el-col span={12}>
              <el-form-item
                label="上报单位"
                required
                prop="createDept"
                rules={{ required: true, message: '上报单位必填' }}>
                <el-select
                  size="small"
                  v-model={form.value.createDept}
                  placeholder="请选择">
                  {commonStore.globalDict['zhdd_org_upload']?.map((item) => (
                    <el-option
                      key={item.dictValue}
                      label={item.dictLabel}
                      value={item.dictValue}
                    />
                  ))}
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col span={12}>
              <el-form-item
                label="事件类型"
                required
                prop="type"
                rules={{ required: true, message: '事件类型必填' }}>
                <el-select
                  size="small"
                  v-model={form.value.type}
                  placeholder="请选择">
                  {commonStore.globalDict['zhdd_incident_type']?.map((item) => (
                    <el-option
                      key={item.dictValue}
                      label={item.dictLabel}
                      value={item.dictValue}
                    />
                  ))}
                </el-select>
              </el-form-item>
            </el-col>
            <el-col span={12}>
              <el-form-item
                label="事件等级"
                required
                prop="level"
                rules={{ required: true, message: '事件等级必填' }}>
                <el-select
                  size="small"
                  v-model={form.value.level}
                  placeholder="请选择">
                  {commonStore.globalDict['zhdd_incident_level']?.map(
                    (item) => (
                      <el-option
                        key={item.dictValue}
                        label={item.dictLabel}
                        value={item.dictValue}
                      />
                    ),
                  )}
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>

          <el-form-item label="事件描述">
            <el-input
              size="small"
              v-model={form.value.des}
              placeholder="请输入"
              type="textarea"
            />
          </el-form-item>

          <el-form-item
            label="事件地点"
            required
            prop="addr"
            rules={{ required: true, message: '事件地点必填' }}>
            <el-input
              v-model={form.value.addr}
              placeholder="请输入"
              size="small"
              onChange={(add: string) => {
                addr.value = add;
              }}
            />
            <QueryMap
              address={addr.value}
              v-model:locations={form.value.locations}
              v-model:longitude={(form.value.locations ?? '').split(',')[0]}
              v-model:latitude={(form.value.locations ?? '').split(',')[1]}
              onChoose={(name) => {
                form.value.addr = name;
              }}
              onRestPositon={() => {
                addr.value = store.incidentDetail.baseInfo?.addr ?? '';
                form.value.addr = store.incidentDetail.baseInfo?.addr;
                form.value.locations = store.incidentDetail.baseInfo?.locations;
              }}
            />
          </el-form-item>
          <el-form-item label="上传视频">
            <MediaUpload
              v-model:media={form.value.video}
              mediaType="video"
              accept="video/*">
              <i class="el-icon-video-play" />
              <span>上传视频</span>
            </MediaUpload>
          </el-form-item>
          <el-form-item label="上传图片">
            <MediaUpload v-model:media={form.value.pic} accept="image/*">
              <i class="el-icon-plus" />
              <span>上传图片</span>
            </MediaUpload>
          </el-form-item>
          <el-form-item>
            <el-button size="small" type="primary" onClick={handleSaveReport}>
              保存
            </el-button>
            <el-button size="small" onClick={() => router.back()}>
              取消
            </el-button>
          </el-form-item>
        </el-form> */}
      </div>
    );
  },
});
